import nsrunit;
unit conversion on;
unit mmHg_ = fundamental;
unit mm=.001 meter^1;
unit mm_sq=1E-6 meter^2;
unit mm_per_mmHg=.001 meter^1*mmHg_^(-1);
unit mmHg_per_mm=1E3 meter^(-1)*mmHg_^1;
unit mmHg_s_per_mm=1E3 meter^(-1)*second^1*mmHg_^1;
unit AU = fundamental;
unit per_Hertz=1 second^1;
unit per_s=1 second^(-1);
unit Beats = fundamental;
unit Beats_per_min=1 second^(-1)*Beats^1;
unit mmHg_s_per_sq_mm=1E6 meter^(-2)*second^1*mmHg_^1;
unit Sec_per_Beat=1 second^1*Beats^(-1);

math main {
	realDomain Time second;
	Time.min=0;
	extern Time.max;
	extern Time.delta;
	real S hertz;
	S=480;
	real Zeta dimensionless;
	Zeta=1;
	real R0 mm;
	R0=1.6;
	real Cwall mm_per_mmHg;
	Cwall=0.006;
	real Kne mmHg_per_mm;
	Kne=1;
	real K1 mmHg_per_mm;
	K1=1.5;
	real K2 mmHg_per_mm;
	K2=3.75;
	real K3 mmHg_per_mm;
	K3=1.05;
	real Bwall mmHg_s_per_sq_mm;
	Bwall=1;
	real B1 mmHg_s_per_mm;
	B1=1;
	real B2 mmHg_s_per_mm;
	B2=10;
	real B3 mmHg_s_per_mm;
	B3=206.973;
	real Tsmax AU;
	Tsmax=4.12;
	real Tpmax AU;
	Tpmax=4.994;
	real Tsmin AU;
	Tsmin=0.5;
	real Tpmin AU;
	Tpmin=1.6;
	real Gcns dimensionless;
	Gcns=1;
	real Gs per_Hertz;
	Gs=0.178;
	real Gp per_Hertz;
	Gp=0.492;
	real tau_nor second;
	tau_nor=9.1;
	real tau_ach second;
	tau_ach=0.2;
	real tau_HR_nor second;
	tau_HR_nor=2.1;
	real tau_HR_ach second;
	tau_HR_ach=2.5;
	real HRo Beats_per_min;
	HRo=282.648;
	real HRmax Beats_per_min;
	HRmax=483.218;
	real HRmin Beats_per_min;
	HRmin=226.238;
	real Beta dimensionless;
	Beta=0.175;
	real delta_th dimensionless;
	delta_th=0;
	real q_nor per_s;
	q_nor=0.1099;
	real q_ach per_s;
	q_ach=5;
	real K_nor AU;
	K_nor=1.12;
	real K_ach AU;
	K_ach=0.65;
	real Gamma dimensionless;
	Gamma=0.75;
	real alpha_cns(Time) hertz;
	real n(Time) hertz;
	real delta(Time) dimensionless;
	real alpha_s0 hertz;
	alpha_s0=58.6;
	real alpha_p0 hertz;
	alpha_p0=76.019;
	real A(Time) mm_sq;
	when(Time=Time.min) A=15.20531;
	real P(Time) mmHg_;
	real R(Time) mm;
	real Eps_1(Time) dimensionless;
	when(Time=Time.min) Eps_1=0.2042;
	real Eps_2(Time) dimensionless;
	when(Time=Time.min) Eps_2=0.183;
	real Eps_3(Time) dimensionless;
	when(Time=Time.min) Eps_3=0.161;
	real Eps_wall(Time) dimensionless;
	real Ts(Time) AU;
	real Tp(Time) AU;
	real c_nor(Time) AU;
	when(Time=Time.min) c_nor=1.441;
	real C_ach(Time) AU;
	when(Time=Time.min) C_ach=1.0;
	real delta_HR_ss(Time) Beats_per_min;
	real delta_HR_smax Beats_per_min;
	real delta_HR_s(Time) Beats_per_min;
	when(Time=Time.min) delta_HR_s=0;
	real delta_HR_ps(Time) Beats_per_min;
	real delta_HR_pmax Beats_per_min;
	real delta_HR_pfast(Time) Beats_per_min;
	real delta_HR_pslow(Time) Beats_per_min;
	when(Time=Time.min) delta_HR_pslow=0;
	real delta_HR_p(Time) Beats_per_min;
	real HR(Time) Beats_per_min;
	real HR_p(Time) Beats_per_min;
	real HR_s(Time) Beats_per_min;
	real Period(Time) Sec_per_Beat;

	// <component name="Environmental">

	// <component name="Parameters">

	// <component name="Nervous_System">
	alpha_cns=(Gcns*n);
	n=(S*(delta-Zeta*delta_th));

	// <component name="Aortic_Wall">
	A:Time=(((-1)*(sqrt(A/3.141592653589793)-R0)/Cwall+P)/Bwall);
	R=((A/3.141592653589793)^.5);
	P=((100 mmHg_)+(10 mmHg_)*sin((5 per_s)*Time));

	// <component name="Coupling_Dynamics">
	Eps_1:Time=((Kne*(Eps_wall-Eps_1)-K1*(Eps_1-Eps_2))/B1+Eps_2:Time);
	Eps_2:Time=((K1*(Eps_1-Eps_2)-K2*(Eps_2-Eps_3)+B1*Eps_1:Time+B2*Eps_3:Time)/(B1+B2));
	Eps_3:Time=((K2*(Eps_2-Eps_3)-K3*Eps_3+B2*Eps_2:Time)/(B2+B3));
	delta=(Eps_wall-Eps_1);
	Eps_wall=((R-R0)/R0);

	// <component name="PNS_tones">
	Ts=(Tsmin+(Tsmax-Tsmin)/(exp(Gs*(alpha_cns-alpha_s0))+1));
	Tp=(Tpmin+(Tpmax-Tpmin)/(exp((-1)*Gp*(alpha_cns-alpha_p0))+1));

	// <component name="Norepinephrine">
	c_nor:Time=((-1)*(c_nor/tau_nor)+q_nor*Ts);

	// <component name="Acetylcholine">
	C_ach:Time=((-1)*(C_ach/tau_ach)+q_ach*Tp);

	// <component name="Heart_Response_Nor">
	delta_HR_ss=(delta_HR_smax*c_nor^2/(K_nor^2+c_nor^2));
	delta_HR_smax=(HRmax-HRo);
	delta_HR_s:Time=(((-1)*delta_HR_s+delta_HR_ss)/tau_HR_nor);

	// <component name="HR_ach">
	delta_HR_ps=(delta_HR_pmax*C_ach^2/(K_ach^2+C_ach^2));
	delta_HR_pmax=(HRo-HRmin);
	delta_HR_pfast=(Gamma*delta_HR_ps);
	delta_HR_pslow:Time=(((-1)*delta_HR_pslow+(1-Gamma)*delta_HR_ps)/tau_HR_ach);
	delta_HR_p=(delta_HR_pfast+delta_HR_pslow);

	// <component name="HR_Combined">
	HR=(HR_p+(HR_s-HRo)*(HR_p-Beta*HRmin)/(HRo-Beta*HRmin));
	HR_s=(HRo+delta_HR_s);
	HR_p=(HRo-delta_HR_p);
	Period=(60/HR);
}
